@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import ContentClassifierType, HumanLoopStatusType, SortOrderType
 
@@ -72,7 +72,7 @@ DescribeHumanLoopResponseTypeDef = TypedDict(
 HumanLoopDataAttributesTypeDef = TypedDict(
     "HumanLoopDataAttributesTypeDef",
     {
-        "ContentClassifiers": List[ContentClassifierType],
+        "ContentClassifiers": Sequence[ContentClassifierType],
     },
 )
 
